import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { SFNServiceException as __BaseException } from "./SFNServiceException";
export declare class ActivityDoesNotExist extends __BaseException {
  readonly name: "ActivityDoesNotExist";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ActivityDoesNotExist, __BaseException>
  );
}
export interface ActivityFailedEventDetails {
  error?: string;
  cause?: string;
}
export declare class ActivityLimitExceeded extends __BaseException {
  readonly name: "ActivityLimitExceeded";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ActivityLimitExceeded, __BaseException>
  );
}
export interface ActivityListItem {
  activityArn: string | undefined;
  name: string | undefined;
  creationDate: Date | undefined;
}
export interface HistoryEventExecutionDataDetails {
  truncated?: boolean;
}
export interface ActivityScheduledEventDetails {
  resource: string | undefined;
  input?: string;
  inputDetails?: HistoryEventExecutionDataDetails;
  timeoutInSeconds?: number;
  heartbeatInSeconds?: number;
}
export interface ActivityScheduleFailedEventDetails {
  error?: string;
  cause?: string;
}
export interface ActivityStartedEventDetails {
  workerName?: string;
}
export interface ActivitySucceededEventDetails {
  output?: string;
  outputDetails?: HistoryEventExecutionDataDetails;
}
export interface ActivityTimedOutEventDetails {
  error?: string;
  cause?: string;
}
export declare class ActivityWorkerLimitExceeded extends __BaseException {
  readonly name: "ActivityWorkerLimitExceeded";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ActivityWorkerLimitExceeded, __BaseException>
  );
}
export interface Tag {
  key?: string;
  value?: string;
}
export interface CreateActivityInput {
  name: string | undefined;
  tags?: Tag[];
}
export interface CreateActivityOutput {
  activityArn: string | undefined;
  creationDate: Date | undefined;
}
export declare class InvalidName extends __BaseException {
  readonly name: "InvalidName";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidName, __BaseException>);
}
export declare class TooManyTags extends __BaseException {
  readonly name: "TooManyTags";
  readonly $fault: "client";
  resourceName?: string;
  constructor(opts: __ExceptionOptionType<TooManyTags, __BaseException>);
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface CloudWatchLogsLogGroup {
  logGroupArn?: string;
}
export interface LogDestination {
  cloudWatchLogsLogGroup?: CloudWatchLogsLogGroup;
}
export declare const LogLevel: {
  readonly ALL: "ALL";
  readonly ERROR: "ERROR";
  readonly FATAL: "FATAL";
  readonly OFF: "OFF";
};
export type LogLevel = (typeof LogLevel)[keyof typeof LogLevel];
export interface LoggingConfiguration {
  level?: LogLevel;
  includeExecutionData?: boolean;
  destinations?: LogDestination[];
}
export interface TracingConfiguration {
  enabled?: boolean;
}
export declare const StateMachineType: {
  readonly EXPRESS: "EXPRESS";
  readonly STANDARD: "STANDARD";
};
export type StateMachineType =
  (typeof StateMachineType)[keyof typeof StateMachineType];
export interface CreateStateMachineInput {
  name: string | undefined;
  definition: string | undefined;
  roleArn: string | undefined;
  type?: StateMachineType;
  loggingConfiguration?: LoggingConfiguration;
  tags?: Tag[];
  tracingConfiguration?: TracingConfiguration;
  publish?: boolean;
  versionDescription?: string;
}
export interface CreateStateMachineOutput {
  stateMachineArn: string | undefined;
  creationDate: Date | undefined;
  stateMachineVersionArn?: string;
}
export declare class InvalidArn extends __BaseException {
  readonly name: "InvalidArn";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidArn, __BaseException>);
}
export declare class InvalidDefinition extends __BaseException {
  readonly name: "InvalidDefinition";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidDefinition, __BaseException>);
}
export declare class InvalidLoggingConfiguration extends __BaseException {
  readonly name: "InvalidLoggingConfiguration";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidLoggingConfiguration, __BaseException>
  );
}
export declare class InvalidTracingConfiguration extends __BaseException {
  readonly name: "InvalidTracingConfiguration";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidTracingConfiguration, __BaseException>
  );
}
export declare class StateMachineAlreadyExists extends __BaseException {
  readonly name: "StateMachineAlreadyExists";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StateMachineAlreadyExists, __BaseException>
  );
}
export declare class StateMachineDeleting extends __BaseException {
  readonly name: "StateMachineDeleting";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StateMachineDeleting, __BaseException>
  );
}
export declare class StateMachineLimitExceeded extends __BaseException {
  readonly name: "StateMachineLimitExceeded";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StateMachineLimitExceeded, __BaseException>
  );
}
export declare class StateMachineTypeNotSupported extends __BaseException {
  readonly name: "StateMachineTypeNotSupported";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StateMachineTypeNotSupported, __BaseException>
  );
}
export declare const ValidationExceptionReason: {
  readonly API_DOES_NOT_SUPPORT_LABELED_ARNS: "API_DOES_NOT_SUPPORT_LABELED_ARNS";
  readonly CANNOT_UPDATE_COMPLETED_MAP_RUN: "CANNOT_UPDATE_COMPLETED_MAP_RUN";
  readonly INVALID_ROUTING_CONFIGURATION: "INVALID_ROUTING_CONFIGURATION";
  readonly MISSING_REQUIRED_PARAMETER: "MISSING_REQUIRED_PARAMETER";
};
export type ValidationExceptionReason =
  (typeof ValidationExceptionReason)[keyof typeof ValidationExceptionReason];
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  reason?: ValidationExceptionReason;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface RoutingConfigurationListItem {
  stateMachineVersionArn: string | undefined;
  weight: number | undefined;
}
export interface CreateStateMachineAliasInput {
  description?: string;
  name: string | undefined;
  routingConfiguration: RoutingConfigurationListItem[] | undefined;
}
export interface CreateStateMachineAliasOutput {
  stateMachineAliasArn: string | undefined;
  creationDate: Date | undefined;
}
export declare class ResourceNotFound extends __BaseException {
  readonly name: "ResourceNotFound";
  readonly $fault: "client";
  resourceName?: string;
  constructor(opts: __ExceptionOptionType<ResourceNotFound, __BaseException>);
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface DeleteActivityInput {
  activityArn: string | undefined;
}
export interface DeleteActivityOutput {}
export interface DeleteStateMachineInput {
  stateMachineArn: string | undefined;
}
export interface DeleteStateMachineOutput {}
export interface DeleteStateMachineAliasInput {
  stateMachineAliasArn: string | undefined;
}
export interface DeleteStateMachineAliasOutput {}
export interface DeleteStateMachineVersionInput {
  stateMachineVersionArn: string | undefined;
}
export interface DeleteStateMachineVersionOutput {}
export interface DescribeActivityInput {
  activityArn: string | undefined;
}
export interface DescribeActivityOutput {
  activityArn: string | undefined;
  name: string | undefined;
  creationDate: Date | undefined;
}
export interface DescribeExecutionInput {
  executionArn: string | undefined;
}
export interface CloudWatchEventsExecutionDataDetails {
  included?: boolean;
}
export declare const ExecutionRedriveStatus: {
  readonly NOT_REDRIVABLE: "NOT_REDRIVABLE";
  readonly REDRIVABLE: "REDRIVABLE";
  readonly REDRIVABLE_BY_MAP_RUN: "REDRIVABLE_BY_MAP_RUN";
};
export type ExecutionRedriveStatus =
  (typeof ExecutionRedriveStatus)[keyof typeof ExecutionRedriveStatus];
export declare const ExecutionStatus: {
  readonly ABORTED: "ABORTED";
  readonly FAILED: "FAILED";
  readonly PENDING_REDRIVE: "PENDING_REDRIVE";
  readonly RUNNING: "RUNNING";
  readonly SUCCEEDED: "SUCCEEDED";
  readonly TIMED_OUT: "TIMED_OUT";
};
export type ExecutionStatus =
  (typeof ExecutionStatus)[keyof typeof ExecutionStatus];
export interface DescribeExecutionOutput {
  executionArn: string | undefined;
  stateMachineArn: string | undefined;
  name?: string;
  status: ExecutionStatus | undefined;
  startDate: Date | undefined;
  stopDate?: Date;
  input?: string;
  inputDetails?: CloudWatchEventsExecutionDataDetails;
  output?: string;
  outputDetails?: CloudWatchEventsExecutionDataDetails;
  traceHeader?: string;
  mapRunArn?: string;
  error?: string;
  cause?: string;
  stateMachineVersionArn?: string;
  stateMachineAliasArn?: string;
  redriveCount?: number;
  redriveDate?: Date;
  redriveStatus?: ExecutionRedriveStatus;
  redriveStatusReason?: string;
}
export declare class ExecutionDoesNotExist extends __BaseException {
  readonly name: "ExecutionDoesNotExist";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ExecutionDoesNotExist, __BaseException>
  );
}
export interface DescribeMapRunInput {
  mapRunArn: string | undefined;
}
export interface MapRunExecutionCounts {
  pending: number | undefined;
  running: number | undefined;
  succeeded: number | undefined;
  failed: number | undefined;
  timedOut: number | undefined;
  aborted: number | undefined;
  total: number | undefined;
  resultsWritten: number | undefined;
  failuresNotRedrivable?: number;
  pendingRedrive?: number;
}
export interface MapRunItemCounts {
  pending: number | undefined;
  running: number | undefined;
  succeeded: number | undefined;
  failed: number | undefined;
  timedOut: number | undefined;
  aborted: number | undefined;
  total: number | undefined;
  resultsWritten: number | undefined;
  failuresNotRedrivable?: number;
  pendingRedrive?: number;
}
export declare const MapRunStatus: {
  readonly ABORTED: "ABORTED";
  readonly FAILED: "FAILED";
  readonly RUNNING: "RUNNING";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type MapRunStatus = (typeof MapRunStatus)[keyof typeof MapRunStatus];
export interface DescribeMapRunOutput {
  mapRunArn: string | undefined;
  executionArn: string | undefined;
  status: MapRunStatus | undefined;
  startDate: Date | undefined;
  stopDate?: Date;
  maxConcurrency: number | undefined;
  toleratedFailurePercentage: number | undefined;
  toleratedFailureCount: number | undefined;
  itemCounts: MapRunItemCounts | undefined;
  executionCounts: MapRunExecutionCounts | undefined;
  redriveCount?: number;
  redriveDate?: Date;
}
export interface DescribeStateMachineInput {
  stateMachineArn: string | undefined;
}
export declare const StateMachineStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly DELETING: "DELETING";
};
export type StateMachineStatus =
  (typeof StateMachineStatus)[keyof typeof StateMachineStatus];
export interface DescribeStateMachineOutput {
  stateMachineArn: string | undefined;
  name: string | undefined;
  status?: StateMachineStatus;
  definition: string | undefined;
  roleArn: string | undefined;
  type: StateMachineType | undefined;
  creationDate: Date | undefined;
  loggingConfiguration?: LoggingConfiguration;
  tracingConfiguration?: TracingConfiguration;
  label?: string;
  revisionId?: string;
  description?: string;
}
export declare class StateMachineDoesNotExist extends __BaseException {
  readonly name: "StateMachineDoesNotExist";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StateMachineDoesNotExist, __BaseException>
  );
}
export interface DescribeStateMachineAliasInput {
  stateMachineAliasArn: string | undefined;
}
export interface DescribeStateMachineAliasOutput {
  stateMachineAliasArn?: string;
  name?: string;
  description?: string;
  routingConfiguration?: RoutingConfigurationListItem[];
  creationDate?: Date;
  updateDate?: Date;
}
export interface DescribeStateMachineForExecutionInput {
  executionArn: string | undefined;
}
export interface DescribeStateMachineForExecutionOutput {
  stateMachineArn: string | undefined;
  name: string | undefined;
  definition: string | undefined;
  roleArn: string | undefined;
  updateDate: Date | undefined;
  loggingConfiguration?: LoggingConfiguration;
  tracingConfiguration?: TracingConfiguration;
  mapRunArn?: string;
  label?: string;
  revisionId?: string;
}
export interface GetActivityTaskInput {
  activityArn: string | undefined;
  workerName?: string;
}
export interface GetActivityTaskOutput {
  taskToken?: string;
  input?: string;
}
export interface GetExecutionHistoryInput {
  executionArn: string | undefined;
  maxResults?: number;
  reverseOrder?: boolean;
  nextToken?: string;
  includeExecutionData?: boolean;
}
export interface ExecutionAbortedEventDetails {
  error?: string;
  cause?: string;
}
export interface ExecutionFailedEventDetails {
  error?: string;
  cause?: string;
}
export interface ExecutionRedrivenEventDetails {
  redriveCount?: number;
}
export interface ExecutionStartedEventDetails {
  input?: string;
  inputDetails?: HistoryEventExecutionDataDetails;
  roleArn?: string;
  stateMachineAliasArn?: string;
  stateMachineVersionArn?: string;
}
export interface ExecutionSucceededEventDetails {
  output?: string;
  outputDetails?: HistoryEventExecutionDataDetails;
}
export interface ExecutionTimedOutEventDetails {
  error?: string;
  cause?: string;
}
export interface LambdaFunctionFailedEventDetails {
  error?: string;
  cause?: string;
}
export interface TaskCredentials {
  roleArn?: string;
}
export interface LambdaFunctionScheduledEventDetails {
  resource: string | undefined;
  input?: string;
  inputDetails?: HistoryEventExecutionDataDetails;
  timeoutInSeconds?: number;
  taskCredentials?: TaskCredentials;
}
export interface LambdaFunctionScheduleFailedEventDetails {
  error?: string;
  cause?: string;
}
export interface LambdaFunctionStartFailedEventDetails {
  error?: string;
  cause?: string;
}
export interface LambdaFunctionSucceededEventDetails {
  output?: string;
  outputDetails?: HistoryEventExecutionDataDetails;
}
export interface LambdaFunctionTimedOutEventDetails {
  error?: string;
  cause?: string;
}
export interface MapIterationEventDetails {
  name?: string;
  index?: number;
}
export interface MapRunFailedEventDetails {
  error?: string;
  cause?: string;
}
export interface MapRunRedrivenEventDetails {
  mapRunArn?: string;
  redriveCount?: number;
}
export interface MapRunStartedEventDetails {
  mapRunArn?: string;
}
export interface MapStateStartedEventDetails {
  length?: number;
}
export interface StateEnteredEventDetails {
  name: string | undefined;
  input?: string;
  inputDetails?: HistoryEventExecutionDataDetails;
}
export interface StateExitedEventDetails {
  name: string | undefined;
  output?: string;
  outputDetails?: HistoryEventExecutionDataDetails;
}
export interface TaskFailedEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  error?: string;
  cause?: string;
}
export interface TaskScheduledEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  region: string | undefined;
  parameters: string | undefined;
  timeoutInSeconds?: number;
  heartbeatInSeconds?: number;
  taskCredentials?: TaskCredentials;
}
export interface TaskStartedEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
}
export interface TaskStartFailedEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  error?: string;
  cause?: string;
}
export interface TaskSubmitFailedEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  error?: string;
  cause?: string;
}
export interface TaskSubmittedEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  output?: string;
  outputDetails?: HistoryEventExecutionDataDetails;
}
export interface TaskSucceededEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  output?: string;
  outputDetails?: HistoryEventExecutionDataDetails;
}
export interface TaskTimedOutEventDetails {
  resourceType: string | undefined;
  resource: string | undefined;
  error?: string;
  cause?: string;
}
export declare const HistoryEventType: {
  readonly ActivityFailed: "ActivityFailed";
  readonly ActivityScheduleFailed: "ActivityScheduleFailed";
  readonly ActivityScheduled: "ActivityScheduled";
  readonly ActivityStarted: "ActivityStarted";
  readonly ActivitySucceeded: "ActivitySucceeded";
  readonly ActivityTimedOut: "ActivityTimedOut";
  readonly ChoiceStateEntered: "ChoiceStateEntered";
  readonly ChoiceStateExited: "ChoiceStateExited";
  readonly ExecutionAborted: "ExecutionAborted";
  readonly ExecutionFailed: "ExecutionFailed";
  readonly ExecutionRedriven: "ExecutionRedriven";
  readonly ExecutionStarted: "ExecutionStarted";
  readonly ExecutionSucceeded: "ExecutionSucceeded";
  readonly ExecutionTimedOut: "ExecutionTimedOut";
  readonly FailStateEntered: "FailStateEntered";
  readonly LambdaFunctionFailed: "LambdaFunctionFailed";
  readonly LambdaFunctionScheduleFailed: "LambdaFunctionScheduleFailed";
  readonly LambdaFunctionScheduled: "LambdaFunctionScheduled";
  readonly LambdaFunctionStartFailed: "LambdaFunctionStartFailed";
  readonly LambdaFunctionStarted: "LambdaFunctionStarted";
  readonly LambdaFunctionSucceeded: "LambdaFunctionSucceeded";
  readonly LambdaFunctionTimedOut: "LambdaFunctionTimedOut";
  readonly MapIterationAborted: "MapIterationAborted";
  readonly MapIterationFailed: "MapIterationFailed";
  readonly MapIterationStarted: "MapIterationStarted";
  readonly MapIterationSucceeded: "MapIterationSucceeded";
  readonly MapRunAborted: "MapRunAborted";
  readonly MapRunFailed: "MapRunFailed";
  readonly MapRunRedriven: "MapRunRedriven";
  readonly MapRunStarted: "MapRunStarted";
  readonly MapRunSucceeded: "MapRunSucceeded";
  readonly MapStateAborted: "MapStateAborted";
  readonly MapStateEntered: "MapStateEntered";
  readonly MapStateExited: "MapStateExited";
  readonly MapStateFailed: "MapStateFailed";
  readonly MapStateStarted: "MapStateStarted";
  readonly MapStateSucceeded: "MapStateSucceeded";
  readonly ParallelStateAborted: "ParallelStateAborted";
  readonly ParallelStateEntered: "ParallelStateEntered";
  readonly ParallelStateExited: "ParallelStateExited";
  readonly ParallelStateFailed: "ParallelStateFailed";
  readonly ParallelStateStarted: "ParallelStateStarted";
  readonly ParallelStateSucceeded: "ParallelStateSucceeded";
  readonly PassStateEntered: "PassStateEntered";
  readonly PassStateExited: "PassStateExited";
  readonly SucceedStateEntered: "SucceedStateEntered";
  readonly SucceedStateExited: "SucceedStateExited";
  readonly TaskFailed: "TaskFailed";
  readonly TaskScheduled: "TaskScheduled";
  readonly TaskStartFailed: "TaskStartFailed";
  readonly TaskStarted: "TaskStarted";
  readonly TaskStateAborted: "TaskStateAborted";
  readonly TaskStateEntered: "TaskStateEntered";
  readonly TaskStateExited: "TaskStateExited";
  readonly TaskSubmitFailed: "TaskSubmitFailed";
  readonly TaskSubmitted: "TaskSubmitted";
  readonly TaskSucceeded: "TaskSucceeded";
  readonly TaskTimedOut: "TaskTimedOut";
  readonly WaitStateAborted: "WaitStateAborted";
  readonly WaitStateEntered: "WaitStateEntered";
  readonly WaitStateExited: "WaitStateExited";
};
export type HistoryEventType =
  (typeof HistoryEventType)[keyof typeof HistoryEventType];
export interface HistoryEvent {
  timestamp: Date | undefined;
  type: HistoryEventType | undefined;
  id: number | undefined;
  previousEventId?: number;
  activityFailedEventDetails?: ActivityFailedEventDetails;
  activityScheduleFailedEventDetails?: ActivityScheduleFailedEventDetails;
  activityScheduledEventDetails?: ActivityScheduledEventDetails;
  activityStartedEventDetails?: ActivityStartedEventDetails;
  activitySucceededEventDetails?: ActivitySucceededEventDetails;
  activityTimedOutEventDetails?: ActivityTimedOutEventDetails;
  taskFailedEventDetails?: TaskFailedEventDetails;
  taskScheduledEventDetails?: TaskScheduledEventDetails;
  taskStartFailedEventDetails?: TaskStartFailedEventDetails;
  taskStartedEventDetails?: TaskStartedEventDetails;
  taskSubmitFailedEventDetails?: TaskSubmitFailedEventDetails;
  taskSubmittedEventDetails?: TaskSubmittedEventDetails;
  taskSucceededEventDetails?: TaskSucceededEventDetails;
  taskTimedOutEventDetails?: TaskTimedOutEventDetails;
  executionFailedEventDetails?: ExecutionFailedEventDetails;
  executionStartedEventDetails?: ExecutionStartedEventDetails;
  executionSucceededEventDetails?: ExecutionSucceededEventDetails;
  executionAbortedEventDetails?: ExecutionAbortedEventDetails;
  executionTimedOutEventDetails?: ExecutionTimedOutEventDetails;
  executionRedrivenEventDetails?: ExecutionRedrivenEventDetails;
  mapStateStartedEventDetails?: MapStateStartedEventDetails;
  mapIterationStartedEventDetails?: MapIterationEventDetails;
  mapIterationSucceededEventDetails?: MapIterationEventDetails;
  mapIterationFailedEventDetails?: MapIterationEventDetails;
  mapIterationAbortedEventDetails?: MapIterationEventDetails;
  lambdaFunctionFailedEventDetails?: LambdaFunctionFailedEventDetails;
  lambdaFunctionScheduleFailedEventDetails?: LambdaFunctionScheduleFailedEventDetails;
  lambdaFunctionScheduledEventDetails?: LambdaFunctionScheduledEventDetails;
  lambdaFunctionStartFailedEventDetails?: LambdaFunctionStartFailedEventDetails;
  lambdaFunctionSucceededEventDetails?: LambdaFunctionSucceededEventDetails;
  lambdaFunctionTimedOutEventDetails?: LambdaFunctionTimedOutEventDetails;
  stateEnteredEventDetails?: StateEnteredEventDetails;
  stateExitedEventDetails?: StateExitedEventDetails;
  mapRunStartedEventDetails?: MapRunStartedEventDetails;
  mapRunFailedEventDetails?: MapRunFailedEventDetails;
  mapRunRedrivenEventDetails?: MapRunRedrivenEventDetails;
}
export interface GetExecutionHistoryOutput {
  events: HistoryEvent[] | undefined;
  nextToken?: string;
}
export declare class InvalidToken extends __BaseException {
  readonly name: "InvalidToken";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidToken, __BaseException>);
}
export interface ListActivitiesInput {
  maxResults?: number;
  nextToken?: string;
}
export interface ListActivitiesOutput {
  activities: ActivityListItem[] | undefined;
  nextToken?: string;
}
export declare const ExecutionRedriveFilter: {
  readonly NOT_REDRIVEN: "NOT_REDRIVEN";
  readonly REDRIVEN: "REDRIVEN";
};
export type ExecutionRedriveFilter =
  (typeof ExecutionRedriveFilter)[keyof typeof ExecutionRedriveFilter];
export interface ListExecutionsInput {
  stateMachineArn?: string;
  statusFilter?: ExecutionStatus;
  maxResults?: number;
  nextToken?: string;
  mapRunArn?: string;
  redriveFilter?: ExecutionRedriveFilter;
}
export interface ExecutionListItem {
  executionArn: string | undefined;
  stateMachineArn: string | undefined;
  name: string | undefined;
  status: ExecutionStatus | undefined;
  startDate: Date | undefined;
  stopDate?: Date;
  mapRunArn?: string;
  itemCount?: number;
  stateMachineVersionArn?: string;
  stateMachineAliasArn?: string;
  redriveCount?: number;
  redriveDate?: Date;
}
export interface ListExecutionsOutput {
  executions: ExecutionListItem[] | undefined;
  nextToken?: string;
}
export interface ListMapRunsInput {
  executionArn: string | undefined;
  maxResults?: number;
  nextToken?: string;
}
export interface MapRunListItem {
  executionArn: string | undefined;
  mapRunArn: string | undefined;
  stateMachineArn: string | undefined;
  startDate: Date | undefined;
  stopDate?: Date;
}
export interface ListMapRunsOutput {
  mapRuns: MapRunListItem[] | undefined;
  nextToken?: string;
}
export interface ListStateMachineAliasesInput {
  stateMachineArn: string | undefined;
  nextToken?: string;
  maxResults?: number;
}
export interface StateMachineAliasListItem {
  stateMachineAliasArn: string | undefined;
  creationDate: Date | undefined;
}
export interface ListStateMachineAliasesOutput {
  stateMachineAliases: StateMachineAliasListItem[] | undefined;
  nextToken?: string;
}
export interface ListStateMachinesInput {
  maxResults?: number;
  nextToken?: string;
}
export interface StateMachineListItem {
  stateMachineArn: string | undefined;
  name: string | undefined;
  type: StateMachineType | undefined;
  creationDate: Date | undefined;
}
export interface ListStateMachinesOutput {
  stateMachines: StateMachineListItem[] | undefined;
  nextToken?: string;
}
export interface ListStateMachineVersionsInput {
  stateMachineArn: string | undefined;
  nextToken?: string;
  maxResults?: number;
}
export interface StateMachineVersionListItem {
  stateMachineVersionArn: string | undefined;
  creationDate: Date | undefined;
}
export interface ListStateMachineVersionsOutput {
  stateMachineVersions: StateMachineVersionListItem[] | undefined;
  nextToken?: string;
}
export interface ListTagsForResourceInput {
  resourceArn: string | undefined;
}
export interface ListTagsForResourceOutput {
  tags?: Tag[];
}
export interface PublishStateMachineVersionInput {
  stateMachineArn: string | undefined;
  revisionId?: string;
  description?: string;
}
export interface PublishStateMachineVersionOutput {
  creationDate: Date | undefined;
  stateMachineVersionArn: string | undefined;
}
export declare class ExecutionLimitExceeded extends __BaseException {
  readonly name: "ExecutionLimitExceeded";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ExecutionLimitExceeded, __BaseException>
  );
}
export declare class ExecutionNotRedrivable extends __BaseException {
  readonly name: "ExecutionNotRedrivable";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ExecutionNotRedrivable, __BaseException>
  );
}
export interface RedriveExecutionInput {
  executionArn: string | undefined;
  clientToken?: string;
}
export interface RedriveExecutionOutput {
  redriveDate: Date | undefined;
}
export interface SendTaskFailureInput {
  taskToken: string | undefined;
  error?: string;
  cause?: string;
}
export interface SendTaskFailureOutput {}
export declare class TaskDoesNotExist extends __BaseException {
  readonly name: "TaskDoesNotExist";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<TaskDoesNotExist, __BaseException>);
}
export declare class TaskTimedOut extends __BaseException {
  readonly name: "TaskTimedOut";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<TaskTimedOut, __BaseException>);
}
export interface SendTaskHeartbeatInput {
  taskToken: string | undefined;
}
export interface SendTaskHeartbeatOutput {}
export declare class InvalidOutput extends __BaseException {
  readonly name: "InvalidOutput";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidOutput, __BaseException>);
}
export interface SendTaskSuccessInput {
  taskToken: string | undefined;
  output: string | undefined;
}
export interface SendTaskSuccessOutput {}
export declare class ExecutionAlreadyExists extends __BaseException {
  readonly name: "ExecutionAlreadyExists";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ExecutionAlreadyExists, __BaseException>
  );
}
export declare class InvalidExecutionInput extends __BaseException {
  readonly name: "InvalidExecutionInput";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidExecutionInput, __BaseException>
  );
}
export interface StartExecutionInput {
  stateMachineArn: string | undefined;
  name?: string;
  input?: string;
  traceHeader?: string;
}
export interface StartExecutionOutput {
  executionArn: string | undefined;
  startDate: Date | undefined;
}
export interface StartSyncExecutionInput {
  stateMachineArn: string | undefined;
  name?: string;
  input?: string;
  traceHeader?: string;
}
export interface BillingDetails {
  billedMemoryUsedInMB?: number;
  billedDurationInMilliseconds?: number;
}
export declare const SyncExecutionStatus: {
  readonly FAILED: "FAILED";
  readonly SUCCEEDED: "SUCCEEDED";
  readonly TIMED_OUT: "TIMED_OUT";
};
export type SyncExecutionStatus =
  (typeof SyncExecutionStatus)[keyof typeof SyncExecutionStatus];
export interface StartSyncExecutionOutput {
  executionArn: string | undefined;
  stateMachineArn?: string;
  name?: string;
  startDate: Date | undefined;
  stopDate: Date | undefined;
  status: SyncExecutionStatus | undefined;
  error?: string;
  cause?: string;
  input?: string;
  inputDetails?: CloudWatchEventsExecutionDataDetails;
  output?: string;
  outputDetails?: CloudWatchEventsExecutionDataDetails;
  traceHeader?: string;
  billingDetails?: BillingDetails;
}
export interface StopExecutionInput {
  executionArn: string | undefined;
  error?: string;
  cause?: string;
}
export interface StopExecutionOutput {
  stopDate: Date | undefined;
}
export interface TagResourceInput {
  resourceArn: string | undefined;
  tags: Tag[] | undefined;
}
export interface TagResourceOutput {}
export declare const InspectionLevel: {
  readonly DEBUG: "DEBUG";
  readonly INFO: "INFO";
  readonly TRACE: "TRACE";
};
export type InspectionLevel =
  (typeof InspectionLevel)[keyof typeof InspectionLevel];
export interface TestStateInput {
  definition: string | undefined;
  roleArn: string | undefined;
  input?: string;
  inspectionLevel?: InspectionLevel;
  revealSecrets?: boolean;
}
export interface InspectionDataRequest {
  protocol?: string;
  method?: string;
  url?: string;
  headers?: string;
  body?: string;
}
export interface InspectionDataResponse {
  protocol?: string;
  statusCode?: string;
  statusMessage?: string;
  headers?: string;
  body?: string;
}
export interface InspectionData {
  input?: string;
  afterInputPath?: string;
  afterParameters?: string;
  result?: string;
  afterResultSelector?: string;
  afterResultPath?: string;
  request?: InspectionDataRequest;
  response?: InspectionDataResponse;
}
export declare const TestExecutionStatus: {
  readonly CAUGHT_ERROR: "CAUGHT_ERROR";
  readonly FAILED: "FAILED";
  readonly RETRIABLE: "RETRIABLE";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type TestExecutionStatus =
  (typeof TestExecutionStatus)[keyof typeof TestExecutionStatus];
export interface TestStateOutput {
  output?: string;
  error?: string;
  cause?: string;
  inspectionData?: InspectionData;
  nextState?: string;
  status?: TestExecutionStatus;
}
export interface UntagResourceInput {
  resourceArn: string | undefined;
  tagKeys: string[] | undefined;
}
export interface UntagResourceOutput {}
export interface UpdateMapRunInput {
  mapRunArn: string | undefined;
  maxConcurrency?: number;
  toleratedFailurePercentage?: number;
  toleratedFailureCount?: number;
}
export interface UpdateMapRunOutput {}
export declare class MissingRequiredParameter extends __BaseException {
  readonly name: "MissingRequiredParameter";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<MissingRequiredParameter, __BaseException>
  );
}
export interface UpdateStateMachineInput {
  stateMachineArn: string | undefined;
  definition?: string;
  roleArn?: string;
  loggingConfiguration?: LoggingConfiguration;
  tracingConfiguration?: TracingConfiguration;
  publish?: boolean;
  versionDescription?: string;
}
export interface UpdateStateMachineOutput {
  updateDate: Date | undefined;
  revisionId?: string;
  stateMachineVersionArn?: string;
}
export interface UpdateStateMachineAliasInput {
  stateMachineAliasArn: string | undefined;
  description?: string;
  routingConfiguration?: RoutingConfigurationListItem[];
}
export interface UpdateStateMachineAliasOutput {
  updateDate: Date | undefined;
}
export interface ValidateStateMachineDefinitionInput {
  definition: string | undefined;
  type?: StateMachineType;
}
export declare const ValidateStateMachineDefinitionSeverity: {
  readonly ERROR: "ERROR";
};
export type ValidateStateMachineDefinitionSeverity =
  (typeof ValidateStateMachineDefinitionSeverity)[keyof typeof ValidateStateMachineDefinitionSeverity];
export interface ValidateStateMachineDefinitionDiagnostic {
  severity: ValidateStateMachineDefinitionSeverity | undefined;
  code: string | undefined;
  message: string | undefined;
  location?: string;
}
export declare const ValidateStateMachineDefinitionResultCode: {
  readonly FAIL: "FAIL";
  readonly OK: "OK";
};
export type ValidateStateMachineDefinitionResultCode =
  (typeof ValidateStateMachineDefinitionResultCode)[keyof typeof ValidateStateMachineDefinitionResultCode];
export interface ValidateStateMachineDefinitionOutput {
  result: ValidateStateMachineDefinitionResultCode | undefined;
  diagnostics: ValidateStateMachineDefinitionDiagnostic[] | undefined;
}
export declare const ActivityFailedEventDetailsFilterSensitiveLog: (
  obj: ActivityFailedEventDetails
) => any;
export declare const ActivityScheduledEventDetailsFilterSensitiveLog: (
  obj: ActivityScheduledEventDetails
) => any;
export declare const ActivityScheduleFailedEventDetailsFilterSensitiveLog: (
  obj: ActivityScheduleFailedEventDetails
) => any;
export declare const ActivitySucceededEventDetailsFilterSensitiveLog: (
  obj: ActivitySucceededEventDetails
) => any;
export declare const ActivityTimedOutEventDetailsFilterSensitiveLog: (
  obj: ActivityTimedOutEventDetails
) => any;
export declare const CreateStateMachineInputFilterSensitiveLog: (
  obj: CreateStateMachineInput
) => any;
export declare const CreateStateMachineAliasInputFilterSensitiveLog: (
  obj: CreateStateMachineAliasInput
) => any;
export declare const DescribeExecutionOutputFilterSensitiveLog: (
  obj: DescribeExecutionOutput
) => any;
export declare const DescribeStateMachineOutputFilterSensitiveLog: (
  obj: DescribeStateMachineOutput
) => any;
export declare const DescribeStateMachineAliasOutputFilterSensitiveLog: (
  obj: DescribeStateMachineAliasOutput
) => any;
export declare const DescribeStateMachineForExecutionOutputFilterSensitiveLog: (
  obj: DescribeStateMachineForExecutionOutput
) => any;
export declare const GetActivityTaskOutputFilterSensitiveLog: (
  obj: GetActivityTaskOutput
) => any;
export declare const ExecutionAbortedEventDetailsFilterSensitiveLog: (
  obj: ExecutionAbortedEventDetails
) => any;
export declare const ExecutionFailedEventDetailsFilterSensitiveLog: (
  obj: ExecutionFailedEventDetails
) => any;
export declare const ExecutionStartedEventDetailsFilterSensitiveLog: (
  obj: ExecutionStartedEventDetails
) => any;
export declare const ExecutionSucceededEventDetailsFilterSensitiveLog: (
  obj: ExecutionSucceededEventDetails
) => any;
export declare const ExecutionTimedOutEventDetailsFilterSensitiveLog: (
  obj: ExecutionTimedOutEventDetails
) => any;
export declare const LambdaFunctionFailedEventDetailsFilterSensitiveLog: (
  obj: LambdaFunctionFailedEventDetails
) => any;
export declare const LambdaFunctionScheduledEventDetailsFilterSensitiveLog: (
  obj: LambdaFunctionScheduledEventDetails
) => any;
export declare const LambdaFunctionScheduleFailedEventDetailsFilterSensitiveLog: (
  obj: LambdaFunctionScheduleFailedEventDetails
) => any;
export declare const LambdaFunctionStartFailedEventDetailsFilterSensitiveLog: (
  obj: LambdaFunctionStartFailedEventDetails
) => any;
export declare const LambdaFunctionSucceededEventDetailsFilterSensitiveLog: (
  obj: LambdaFunctionSucceededEventDetails
) => any;
export declare const LambdaFunctionTimedOutEventDetailsFilterSensitiveLog: (
  obj: LambdaFunctionTimedOutEventDetails
) => any;
export declare const MapRunFailedEventDetailsFilterSensitiveLog: (
  obj: MapRunFailedEventDetails
) => any;
export declare const StateEnteredEventDetailsFilterSensitiveLog: (
  obj: StateEnteredEventDetails
) => any;
export declare const StateExitedEventDetailsFilterSensitiveLog: (
  obj: StateExitedEventDetails
) => any;
export declare const TaskFailedEventDetailsFilterSensitiveLog: (
  obj: TaskFailedEventDetails
) => any;
export declare const TaskScheduledEventDetailsFilterSensitiveLog: (
  obj: TaskScheduledEventDetails
) => any;
export declare const TaskStartFailedEventDetailsFilterSensitiveLog: (
  obj: TaskStartFailedEventDetails
) => any;
export declare const TaskSubmitFailedEventDetailsFilterSensitiveLog: (
  obj: TaskSubmitFailedEventDetails
) => any;
export declare const TaskSubmittedEventDetailsFilterSensitiveLog: (
  obj: TaskSubmittedEventDetails
) => any;
export declare const TaskSucceededEventDetailsFilterSensitiveLog: (
  obj: TaskSucceededEventDetails
) => any;
export declare const TaskTimedOutEventDetailsFilterSensitiveLog: (
  obj: TaskTimedOutEventDetails
) => any;
export declare const HistoryEventFilterSensitiveLog: (obj: HistoryEvent) => any;
export declare const GetExecutionHistoryOutputFilterSensitiveLog: (
  obj: GetExecutionHistoryOutput
) => any;
export declare const PublishStateMachineVersionInputFilterSensitiveLog: (
  obj: PublishStateMachineVersionInput
) => any;
export declare const SendTaskFailureInputFilterSensitiveLog: (
  obj: SendTaskFailureInput
) => any;
export declare const SendTaskSuccessInputFilterSensitiveLog: (
  obj: SendTaskSuccessInput
) => any;
export declare const StartExecutionInputFilterSensitiveLog: (
  obj: StartExecutionInput
) => any;
export declare const StartSyncExecutionInputFilterSensitiveLog: (
  obj: StartSyncExecutionInput
) => any;
export declare const StartSyncExecutionOutputFilterSensitiveLog: (
  obj: StartSyncExecutionOutput
) => any;
export declare const StopExecutionInputFilterSensitiveLog: (
  obj: StopExecutionInput
) => any;
export declare const TestStateInputFilterSensitiveLog: (
  obj: TestStateInput
) => any;
export declare const InspectionDataFilterSensitiveLog: (
  obj: InspectionData
) => any;
export declare const TestStateOutputFilterSensitiveLog: (
  obj: TestStateOutput
) => any;
export declare const UpdateStateMachineInputFilterSensitiveLog: (
  obj: UpdateStateMachineInput
) => any;
export declare const UpdateStateMachineAliasInputFilterSensitiveLog: (
  obj: UpdateStateMachineAliasInput
) => any;
export declare const ValidateStateMachineDefinitionInputFilterSensitiveLog: (
  obj: ValidateStateMachineDefinitionInput
) => any;
